/* execute3.c
 *
 * Last edited: 2017-07-16 15:25:24 by piumarta on zora
 */

#include <stdio.h>
#include <stdlib.h>
#include <ctype.h>

int program[1024];
int reg[32];
int mem[256];

void expected(char * what, int c)
{
    fprintf(stderr, "expected %s near: ", what);
    if (EOF == c) fprintf(stderr, "end of file");
    else
	do {
	    fputc(c, stderr);
	    c= getchar();
	} while (EOF != c);
    fprintf(stderr, "\n");
    exit(1);
}

int main(int argc, char **argv)
{
    int pc= 0;
    int c= getchar();
    if ('[' != c) expected("']'", c);
    c= getchar();
    for (;;) {
	while (isspace(c)) c= getchar();
	if (isdigit(c)) {
	    int i= 0;
	    do {
		i= i * 10 + c - '0';
		c= getchar();
	    } while (isdigit(c));
	    program[pc++]= i;
	    if (']' == c) break;
	    if (',' != c) expected("']' or ','", c);
	    c= getchar();
	}
	else if (']' == c) break;
	else
	    expected("']' or number", c);
    }

    pc= 0;
    for (;;) {
	switch (program[pc++]) {
	    case 0: {  // loadi reg imm
		int r= program[pc++];
		int i= program[pc++];
		reg[r]= i;
		continue;
	    }
	    case 1: {  // load reg mem
		int r= program[pc++];
		int m= program[pc++];
		reg[r]= mem[m];
		continue;
	    }
	    case 2: {  // store reg mem
		int r= program[pc++];
		int m= program[pc++];
		mem[m]= reg[r];
		continue;
	    }
	    case 3: {  // less reg reg
		int r1= program[pc++];
		int r2= program[pc++];
		reg[r1]= reg[r1] < reg[r2];
		continue;
	    }
	    case 4: {  // add reg reg
		int r1= program[pc++];
		int r2= program[pc++];
		reg[r1] += reg[r2];
		continue;
	    }
	    case 5: {  // sub reg reg
		int r1= program[pc++];
		int r2= program[pc++];
		reg[r1] -= reg[r2];
		continue;
	    }
	    case 6: {  // mul reg reg
		int r1= program[pc++];
		int r2= program[pc++];
		reg[r1] *= reg[r2];
		continue;
	    }
	    case 7: {  // div reg reg
		int r1= program[pc++];
		int r2= program[pc++];
		reg[r1] /= reg[r2];
		continue;
	    }
	    case 8: {  // mod reg reg
		int r1= program[pc++];
		int r2= program[pc++];
		reg[r1] %= reg[r2];
		continue;
	    }
	    case 9: {  // jump progaddr
		pc= program[pc];
		continue;
	    }
	    case 10: {  // jumpf reg progaddr
		int r= program[pc++];
		int p= program[pc++];
		if (!reg[r]) pc= p;
		continue;
	    }
	    case 11: {  // out reg
		int r= program[pc++];
		printf("%i\n", reg[r]);
		continue;
	    }
	    case 12: {  // halt
		printf("halt\n");
		exit(0);
	    }
	    default:
		fprintf(stderr, "illegal instruction: %i\n", program[pc-1]);
		exit(1);
	}
    }

    return 0;
}
