import sys

string   = None
position = None
limit    = None

def peek():
    global string, position, limit
    if position < limit: return string[position]
    return ""

def next():
    global string, position, limit
    if position < limit:
        c = string[position]
        position += 1
        return c
    return ""

def rewind(pos):
    global string, position, limit
    position = pos

def skipSpace():
    global string, position, limit
    while peek().isspace(): next()

def matchChar(x):
    global string, position, limit
    if peek() == x:
        next()
        skipSpace()
        return x
    return ""

def matchString(x):
    global string, position, limit
    pos = position
    for c in x:
        if c != next():
            rewind(pos)
            return ""
    skipSpace()
    return x

def matchClass(guard):
    global string, position, limit
    result = ""
    if guard(peek()):
        while guard(peek()):
            result += next();
        skipSpace()
        return result
    return ""

result = None

def succeed(pos, res):
    global result
    rewind(pos)
    result = res
    return res

def fail(pos):
    global string, position, limit, result
    rewind(pos)
    return False

def expected(what):
    global string, position, limit, result
    print("expected " + what + " near `" + scanner.read(20) + "'")
    exit()

def parseInt():
    global string, position, limit, result
    pos = position
    result = matchClass(str.isdigit)
    if not result: return fail(pos)
    result = ['int', int(result)]
    return result

def parseId():
    global string, position, limit, result
    pos = position
    result = matchClass(str.isalpha)
    if not result: return fail(pos)
    result = ['id', result]
    return result

def parsePrimary():
    global string, position, limit, result
    if parseId() or parseInt(): return result
    pos = position
    if matchChar('('):
        if not parseExpr(): expected("expression")
        lhs = result
        if not matchChar(')'): expected("`)'")
        result = lhs
        return lhs
    return fail(pos)

def parseMul():
    global string, position, limit, result
    pos = position
    if parsePrimary():
        lhs = result
        pos = position
        while True:
            if matchChar("*"):
                if not parsePrimary(): expected("primary")
                lhs = ["mul", lhs, result];
                pos = position
                continue
            if matchChar("/"):
                if not parsePrimary(): expected("primary")
                lhs = ["div", lhs, result];
                pos = position
                continue
            if matchChar("%"):
                if not parsePrimary(): expected("primary")
                lhs = ["mod", lhs, result];
                pos = position
                continue
            break
        return succeed(pos, lhs)
    return False

def parseAdd():
    global string, position, limit, result
    pos = position
    if parseMul():
        lhs = result
        pos = position
        while True:
            if matchChar("+"):
                if not parseMul(): expected("expression")
                lhs = ["add", lhs, result];
                pos = position
                continue
            break
        return succeed(pos, lhs)
    return False

def parseRelation():
    global string, position, limit, result
    if not parseAdd(): return False
    lhs = result
    pos = position
    if (matchChar("<")):
        if not parseAdd(): expected("expression")
        result= ["less", lhs, result]
        return result
    return succeed(pos, lhs)

def parseAssign():
    global string, position, limit, result
    pos = position
    if parseId():
        lhs = result
        if matchChar('='):
            if not parseExpr(): expected("expression")
            rhs = result
            result = ["assign", lhs, rhs]
            return result
    return fail(pos)

def parseExpr():
    global string, position, limit, result
    return parseAssign() or parseRelation()

def parsePrint():
    global string, position, limit, result
    pos = position
    if matchString("print"):
        if not parseExpr(): expected("expression")
        result = ["print", result]
        return result
    return fail(pos)

def parseWhile():
    global string, position, limit, result
    pos = position
    if matchString("while"):
        if not parseExpr(): expected("expression")
        condition = result
        if not matchChar(":"): expected("`:'")
        if not parseStatement(): expected("statement")
        body = result
        result = ["while", condition, body]
        return result
    return fail(pos)

def parseStatement():
    return parsePrint() or parseWhile() or parseExpr()

string   = sys.stdin.read()
position = 0
limit    = len(string)

skipSpace()

while True:
    t = parseStatement()
    if not t: break
    print(t)
